/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
 *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 *
 *  Copyright (C) 2009 Sun Microsystems
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/**
 * @file Implementation of the AlterInfo class
 */

#include "config.h"
#include "drizzled/alter_info.h"
#include "drizzled/alter_drop.h"
#include "drizzled/alter_column.h"
#include "drizzled/key.h"
#include "drizzled/create_field.h"

namespace drizzled
{

AlterInfo::AlterInfo() :
  flags(),
  keys_onoff(LEAVE_AS_IS),
  tablespace_op(NO_TABLESPACE_OP),
  no_parts(0),
  build_method(HA_BUILD_DEFAULT),
  datetime_field(NULL),
  error_if_not_empty(false)
{}

} /* namespace drizzled */
